quasiSpectral: Compare mutant to wild type spectral count data, using...

Description Usage Arguments Value

View source: R/quasiSpectral.r

Description

Compare mutant to wild type spectral count data, using "QuasiSeq" methodology

Usage

1
quasiSpectral(spectralDataAll, n.mut, n.wt)

Arguments

spectralDataAll

data frame of gene/protein identifiers (geneName) and their spectral counts in mutant and wildtype groups.

n.mut

number of mutant animals

n.wt

number of wild type animals

Value

A dataframe with the log2 ratios, p-values, and q-values. Also eta0, the estimated proportion of null samples


mooredf22/quasispectral documentation built on May 17, 2021, 1:20 a.m.