Description Usage Arguments Value
View source: R/quasiSpectral.r
Compare mutant to wild type spectral count data, using "QuasiSeq" methodology
1 | quasiSpectral(spectralDataAll, n.mut, n.wt)
|
spectralDataAll |
data frame of gene/protein identifiers (geneName) and their spectral counts in mutant and wildtype groups. |
n.mut |
number of mutant animals |
n.wt |
number of wild type animals |
A dataframe with the log2 ratios, p-values, and q-values. Also eta0, the estimated proportion of null samples
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.